Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(399)

Unified Diff: remoting/host/screen_recorder.h

Issue 9827006: Refactor VideoStub interface to accept ownership of video packets. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/chromoting_host_unittest.cc ('k') | remoting/host/screen_recorder.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/screen_recorder.h
diff --git a/remoting/host/screen_recorder.h b/remoting/host/screen_recorder.h
index c6554e4dc1b9c6859148b9355fead058987b677d..ae39b69f240d8f350af6a858df34e6cbff21af2d 100644
--- a/remoting/host/screen_recorder.h
+++ b/remoting/host/screen_recorder.h
@@ -133,8 +133,9 @@ class ScreenRecorder : public base::RefCountedThreadSafe<ScreenRecorder> {
// Signal network thread to cease activities.
void DoStopOnNetworkThread(const base::Closure& done_task);
- // Callback for VideoStub::ProcessVideoPacket().
- void VideoPacketSentCallback(scoped_ptr<VideoPacket> packet);
+ // Callback for VideoStub::ProcessVideoPacket() that is used for
+ // each last packet in a frame.
+ void VideoFrameSentCallback();
// Encoder thread -----------------------------------------------------------
« no previous file with comments | « remoting/host/chromoting_host_unittest.cc ('k') | remoting/host/screen_recorder.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698